==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_entities/standardworkorder_001/StandardWorkOrder.java <==

package net.datastream.schemas.mp_entities.standardworkorder_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CATEGORYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.PRIORITY;
import net.datastream.schemas.mp_fields.PROBLEMCODEID;
import net.datastream.schemas.mp_fields.STDWOID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDWO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DURATION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRIORITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROBLEMCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERCLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTOFSERVICE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/StandardWorkOrder_001}UserDefinedFields" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYDATEREVIEWREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYREVIEWEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERMITDATEREVIEWREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERMITREVIEWEDBY" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "standardwo",
    "workordertype",
    "duration",
    "priority",
    "type",
    "problemcodeid",
    "categoryid",
    "classid",
    "workorderclassid",
    "equipmentclassid",
    "outofservice",
    "userdefinedarea",
    "userDefinedFields",
    "safetydatereviewrequired",
    "safetyreviewedby",
    "permitdatereviewrequired",
    "permitreviewedby"
})
@XmlRootElement(name = "StandardWorkOrder")
public class StandardWorkOrder {

    @XmlElement(name = "STANDARDWO", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STDWOID_Type standardwo;
    @XmlElement(name = "WORKORDERTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TYPE_Type workordertype;
    @XmlElement(name = "DURATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected long duration;
    @XmlElement(name = "PRIORITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected PRIORITY priority;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type type;
    @XmlElement(name = "PROBLEMCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PROBLEMCODEID problemcodeid;
    @XmlElement(name = "CATEGORYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CATEGORYID categoryid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "WORKORDERCLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type workorderclassid;
    @XmlElement(name = "EQUIPMENTCLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type equipmentclassid;
    @XmlElement(name = "OUTOFSERVICE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String outofservice;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlElement(name = "UserDefinedFields")
    protected UserDefinedFields userDefinedFields;
    @XmlElement(name = "SAFETYDATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME safetydatereviewrequired;
    @XmlElement(name = "SAFETYREVIEWEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type safetyreviewedby;
    @XmlElement(name = "PERMITDATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME permitdatereviewrequired;
    @XmlElement(name = "PERMITREVIEWEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type permitreviewedby;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété standardwo.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getSTANDARDWO() {
        return standardwo;
    }

    /**
     * Définit la valeur de la propriété standardwo.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setSTANDARDWO(STDWOID_Type value) {
        this.standardwo = value;
    }

    /**
     * Obtient la valeur de la propriété workordertype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWORKORDERTYPE() {
        return workordertype;
    }

    /**
     * Définit la valeur de la propriété workordertype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWORKORDERTYPE(TYPE_Type value) {
        this.workordertype = value;
    }

    /**
     * Obtient la valeur de la propriété duration.
     * 
     */
    public long getDURATION() {
        return duration;
    }

    /**
     * Définit la valeur de la propriété duration.
     * 
     */
    public void setDURATION(long value) {
        this.duration = value;
    }

    /**
     * Obtient la valeur de la propriété priority.
     * 
     * @return
     *     possible object is
     *     {@link PRIORITY }
     *     
     */
    public PRIORITY getPRIORITY() {
        return priority;
    }

    /**
     * Définit la valeur de la propriété priority.
     * 
     * @param value
     *     allowed object is
     *     {@link PRIORITY }
     *     
     */
    public void setPRIORITY(PRIORITY value) {
        this.priority = value;
    }

    /**
     * Obtient la valeur de la propriété type.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Définit la valeur de la propriété type.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Obtient la valeur de la propriété problemcodeid.
     * 
     * @return
     *     possible object is
     *     {@link PROBLEMCODEID }
     *     
     */
    public PROBLEMCODEID getPROBLEMCODEID() {
        return problemcodeid;
    }

    /**
     * Définit la valeur de la propriété problemcodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link PROBLEMCODEID }
     *     
     */
    public void setPROBLEMCODEID(PROBLEMCODEID value) {
        this.problemcodeid = value;
    }

    /**
     * Obtient la valeur de la propriété categoryid.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Définit la valeur de la propriété categoryid.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété workorderclassid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getWORKORDERCLASSID() {
        return workorderclassid;
    }

    /**
     * Définit la valeur de la propriété workorderclassid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setWORKORDERCLASSID(CLASSID_Type value) {
        this.workorderclassid = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentclassid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getEQUIPMENTCLASSID() {
        return equipmentclassid;
    }

    /**
     * Définit la valeur de la propriété equipmentclassid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setEQUIPMENTCLASSID(CLASSID_Type value) {
        this.equipmentclassid = value;
    }

    /**
     * Obtient la valeur de la propriété outofservice.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSERVICE() {
        return outofservice;
    }

    /**
     * Définit la valeur de la propriété outofservice.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSERVICE(String value) {
        this.outofservice = value;
    }

    /**
     * Obtient la valeur de la propriété userdefinedarea.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Définit la valeur de la propriété userdefinedarea.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Obtient la valeur de la propriété userDefinedFields.
     * 
     * @return
     *     possible object is
     *     {@link UserDefinedFields }
     *     
     */
    public UserDefinedFields getUserDefinedFields() {
        return userDefinedFields;
    }

    /**
     * Définit la valeur de la propriété userDefinedFields.
     * 
     * @param value
     *     allowed object is
     *     {@link UserDefinedFields }
     *     
     */
    public void setUserDefinedFields(UserDefinedFields value) {
        this.userDefinedFields = value;
    }

    /**
     * Obtient la valeur de la propriété safetydatereviewrequired.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSAFETYDATEREVIEWREQUIRED() {
        return safetydatereviewrequired;
    }

    /**
     * Définit la valeur de la propriété safetydatereviewrequired.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSAFETYDATEREVIEWREQUIRED(DATETIME value) {
        this.safetydatereviewrequired = value;
    }

    /**
     * Obtient la valeur de la propriété safetyreviewedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getSAFETYREVIEWEDBY() {
        return safetyreviewedby;
    }

    /**
     * Définit la valeur de la propriété safetyreviewedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setSAFETYREVIEWEDBY(USERID_Type value) {
        this.safetyreviewedby = value;
    }

    /**
     * Obtient la valeur de la propriété permitdatereviewrequired.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPERMITDATEREVIEWREQUIRED() {
        return permitdatereviewrequired;
    }

    /**
     * Définit la valeur de la propriété permitdatereviewrequired.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPERMITDATEREVIEWREQUIRED(DATETIME value) {
        this.permitdatereviewrequired = value;
    }

    /**
     * Obtient la valeur de la propriété permitreviewedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getPERMITREVIEWEDBY() {
        return permitreviewedby;
    }

    /**
     * Définit la valeur de la propriété permitreviewedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setPERMITREVIEWEDBY(USERID_Type value) {
        this.permitreviewedby = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_entities/standardworkorder_001/StandardWorkOrder.java <==

package net.datastream.schemas.mp_entities.standardworkorder_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CATEGORYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.PRIORITY;
import net.datastream.schemas.mp_fields.PROBLEMCODEID;
import net.datastream.schemas.mp_fields.STDWOID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDWO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DURATION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRIORITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROBLEMCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERCLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTOFSERVICE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/StandardWorkOrder_001}UserDefinedFields" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYDATEREVIEWREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYREVIEWEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERMITDATEREVIEWREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERMITREVIEWEDBY" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "standardwo",
    "workordertype",
    "duration",
    "priority",
    "type",
    "problemcodeid",
    "categoryid",
    "classid",
    "workorderclassid",
    "equipmentclassid",
    "outofservice",
    "userdefinedarea",
    "userDefinedFields",
    "safetydatereviewrequired",
    "safetyreviewedby",
    "permitdatereviewrequired",
    "permitreviewedby"
})
@XmlRootElement(name = "StandardWorkOrder")
public class StandardWorkOrder {

    @XmlElement(name = "STANDARDWO", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STDWOID_Type standardwo;
    @XmlElement(name = "WORKORDERTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TYPE_Type workordertype;
    @XmlElement(name = "DURATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected long duration;
    @XmlElement(name = "PRIORITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected PRIORITY priority;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type type;
    @XmlElement(name = "PROBLEMCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PROBLEMCODEID problemcodeid;
    @XmlElement(name = "CATEGORYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CATEGORYID categoryid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "WORKORDERCLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type workorderclassid;
    @XmlElement(name = "EQUIPMENTCLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type equipmentclassid;
    @XmlElement(name = "OUTOFSERVICE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String outofservice;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlElement(name = "UserDefinedFields")
    protected UserDefinedFields userDefinedFields;
    @XmlElement(name = "SAFETYDATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME safetydatereviewrequired;
    @XmlElement(name = "SAFETYREVIEWEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type safetyreviewedby;
    @XmlElement(name = "PERMITDATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME permitdatereviewrequired;
    @XmlElement(name = "PERMITREVIEWEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type permitreviewedby;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the standardwo property.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getSTANDARDWO() {
        return standardwo;
    }

    /**
     * Sets the value of the standardwo property.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setSTANDARDWO(STDWOID_Type value) {
        this.standardwo = value;
    }

    /**
     * Gets the value of the workordertype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWORKORDERTYPE() {
        return workordertype;
    }

    /**
     * Sets the value of the workordertype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWORKORDERTYPE(TYPE_Type value) {
        this.workordertype = value;
    }

    /**
     * Gets the value of the duration property.
     * 
     */
    public long getDURATION() {
        return duration;
    }

    /**
     * Sets the value of the duration property.
     * 
     */
    public void setDURATION(long value) {
        this.duration = value;
    }

    /**
     * Gets the value of the priority property.
     * 
     * @return
     *     possible object is
     *     {@link PRIORITY }
     *     
     */
    public PRIORITY getPRIORITY() {
        return priority;
    }

    /**
     * Sets the value of the priority property.
     * 
     * @param value
     *     allowed object is
     *     {@link PRIORITY }
     *     
     */
    public void setPRIORITY(PRIORITY value) {
        this.priority = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the problemcodeid property.
     * 
     * @return
     *     possible object is
     *     {@link PROBLEMCODEID }
     *     
     */
    public PROBLEMCODEID getPROBLEMCODEID() {
        return problemcodeid;
    }

    /**
     * Sets the value of the problemcodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PROBLEMCODEID }
     *     
     */
    public void setPROBLEMCODEID(PROBLEMCODEID value) {
        this.problemcodeid = value;
    }

    /**
     * Gets the value of the categoryid property.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Sets the value of the categoryid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the workorderclassid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getWORKORDERCLASSID() {
        return workorderclassid;
    }

    /**
     * Sets the value of the workorderclassid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setWORKORDERCLASSID(CLASSID_Type value) {
        this.workorderclassid = value;
    }

    /**
     * Gets the value of the equipmentclassid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getEQUIPMENTCLASSID() {
        return equipmentclassid;
    }

    /**
     * Sets the value of the equipmentclassid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setEQUIPMENTCLASSID(CLASSID_Type value) {
        this.equipmentclassid = value;
    }

    /**
     * Gets the value of the outofservice property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSERVICE() {
        return outofservice;
    }

    /**
     * Sets the value of the outofservice property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSERVICE(String value) {
        this.outofservice = value;
    }

    /**
     * Gets the value of the userdefinedarea property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Sets the value of the userdefinedarea property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Gets the value of the userDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link UserDefinedFields }
     *     
     */
    public UserDefinedFields getUserDefinedFields() {
        return userDefinedFields;
    }

    /**
     * Sets the value of the userDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link UserDefinedFields }
     *     
     */
    public void setUserDefinedFields(UserDefinedFields value) {
        this.userDefinedFields = value;
    }

    /**
     * Gets the value of the safetydatereviewrequired property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSAFETYDATEREVIEWREQUIRED() {
        return safetydatereviewrequired;
    }

    /**
     * Sets the value of the safetydatereviewrequired property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSAFETYDATEREVIEWREQUIRED(DATETIME value) {
        this.safetydatereviewrequired = value;
    }

    /**
     * Gets the value of the safetyreviewedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getSAFETYREVIEWEDBY() {
        return safetyreviewedby;
    }

    /**
     * Sets the value of the safetyreviewedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setSAFETYREVIEWEDBY(USERID_Type value) {
        this.safetyreviewedby = value;
    }

    /**
     * Gets the value of the permitdatereviewrequired property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPERMITDATEREVIEWREQUIRED() {
        return permitdatereviewrequired;
    }

    /**
     * Sets the value of the permitdatereviewrequired property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPERMITDATEREVIEWREQUIRED(DATETIME value) {
        this.permitdatereviewrequired = value;
    }

    /**
     * Gets the value of the permitreviewedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getPERMITREVIEWEDBY() {
        return permitreviewedby;
    }

    /**
     * Sets the value of the permitreviewedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setPERMITREVIEWEDBY(USERID_Type value) {
        this.permitreviewedby = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
